aboutsummaryrefslogtreecommitdiffstats
path: root/epan/column-utils.h
diff options
context:
space:
mode:
authorJoão Valverde <joao.valverde@tecnico.ulisboa.pt>2015-10-15 02:44:04 +0100
committerMichael Mann <mmann78@netscape.net>2015-11-07 21:15:11 +0000
commit24bfb7e35d619c004e0458f38a1d5ae538a898fb (patch)
tree643dbf00491cb77bedcf715a30467c1d77606bd8 /epan/column-utils.h
parent31f004f1caee87d744610f48c93fae1efa8e7b56 (diff)
column-utils: Refactor col_append_port() to col_append_ports()
Having a single function call to format source-destination port column info serves the current (and presently only) use case better by having a single place to manage the display format. This commit does not introduce any actual formatting changes. Change-Id: I1d479d0fd5690d12afb47e538057fdc2dd369ca2 Reviewed-on: https://code.wireshark.org/review/11539 Petri-Dish: Michael Mann <mmann78@netscape.net> Tested-by: Petri Dish Buildbot <buildbot-no-reply@wireshark.org> Reviewed-by: Michael Mann <mmann78@netscape.net>
Diffstat (limited to 'epan/column-utils.h')
-rw-r--r--epan/column-utils.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/epan/column-utils.h b/epan/column-utils.h
index d89a745678..5c5a83cd7b 100644
--- a/epan/column-utils.h
+++ b/epan/column-utils.h
@@ -279,15 +279,15 @@ WS_DLL_PUBLIC void col_append_str(column_info *cinfo, const gint col, const gcha
*/
WS_DLL_PUBLIC void col_append_str_uint(column_info *cinfo, const gint col, const gchar *abbrev, guint32 val, const gchar *sep);
-/** Append a transport port to a column element, the text will be copied.
+/** Append a transport port pair to a column element, the text will be copied.
*
* @param cinfo the current packet row
* @param col the column to use, e.g. COL_INFO
* @param typ the port type to resolve
* @param val the port value to append
* @param sep an optional separator to _prepend_ to the port string
*/
-WS_DLL_PUBLIC void col_append_port(column_info *cinfo, const gint col, port_type typ, guint16 val, const gchar *sep);
+WS_DLL_PUBLIC void col_append_ports(column_info *cinfo, const gint col, port_type typ, guint16 src, guint16 dst);
/* Append the given strings (terminated by COL_ADD_LSTR_TERMINATOR) to a column element,
*
@@ -279,15 +279,15 @@ WS_DLL_PUBLIC void col_append_str(column_info *cinfo, const gint col, const gcha
* @param cinfo the current packet row
* @param col the column to use, e.g. COL_INFO
- * @param typ the port type to resolve
- * @param val the port value to append
- * @param sep an optional separator to _prepend_ to the port string
+ * @param typ the port type to resolve, e.g. PT_UDP
+ * @param src the source port value to append
+ * @param dst the destination port value to append
*/